<-- See comments in nototools/extract_ohchr_attributions.py for information on the origin and purpose of this file. -->

Translation | Translation Source
--- | ---
Abkhaz | Office of the High Commissioner for Human Rights - Georgia Field Office
Achehnese | Asnawi Ali
Achuar Chicham | Office of the High Commissioner for Human Rights - Ecuador Field Office
Achuar-Shiwiar | Coordinadora Nacional de Derechos Humanos, Peru
Adja | Commission béninoise des Droits de l'Homme, Benin
Adyghe | Federation of Caucasian Assocations in Turkey (Kaffed)
Afaan Oromo (Oromiffa) | Dema Translation and Editing Service
Afrikaans | United Nations Information Centre, Namibia
Aguaruna | Coordinadora Nacional de Derechos Humanos, Peru
A'ingae | Office of the High Commissioner for Human Rights - Ecuador Field Office
Akuapem Twi | National Association of Negro Business and Professional Women's Clubs, US
Albanian | United Nations Department of Public Information, NY
Altay | Office of the High Commissioner for Human Rights - Russian Federation
Amahuaca | Coordinadora Nacional de Derechos Humanos, Peru
Amarakaeri | Coordinadora Nacional de Derechos Humanos, Peru
Amazigh | Réseau Amazigh pour la Citoyenneté
Amharic | National Commission for UNESCO, Ethiopia
Amuesha-Yanesha | Coordinadora Nacional de Derechos Humanos, Peru
Ao | People’s Watch, India
Arabela | Coordinadora Nacional de Derechos Humanos, Peru
Arabic (Alarabia) | United Nations Department of Public Information, NY
Armenian | United Nations Department of Public Information, NY
Asante | National Association of Negro Business and Professional Women's Clubs, US
Asháninca | Coordinadora Nacional de Derechos Humanos, Peru
Ashéninca | Coordinadora Nacional de Derechos Humanos, Peru
Assamese | United Nations Department of Public Information, NY
Assyrian (Atoraya) | Journal of Assyrian Academic Studies, USA (Philimon Darmo)
Asturian (Bable) | Academia de la Llingua Asturiana, Spain
Awadhi | People’s Watch, India
Awapit | Office of the High Commissioner for Human Rights - Ecuador Field Office
Aymara | Coordinadora Nacional de Derechos Humanos, Peru
Azeri/Azerbaijani (Cyrillic) | United Nations Department of Public Information, NY
Azeri/Azerbaijani (Latin) | United Nations Department of Public Information, NY
Bable (Asturian) | Academia de la Llingua Asturiana, Spain
Bahasa Indonesia | United Nations Information Centre, Indonesia
Bahasa Melayu (Malay) | Diffusion Multilingue des Droits de l'Homme, France
Bai Coca | Office of the High Commissioner for Human Rights - Ecuador Field Office
Balanda Viri | United Nations Mission In Sudan
Balinese | United Nations Information Centre, Indonesia
Balochi | United Nations Information Centre, Pakistan
Bambara | Diffusion Multilingue des Droits de l'Homme, France, in cooperation with l'Agence de Coopération Culturelle et Technique
Baoulé/Baule | Diffusion Multilingue des Droits de l'Homme, France
Baram | Nepal Baram Association
Bari | United Nations Mission In Sudan
Basque (Euskara) | United Nations Information Centre, Spain
Batonu (Bariba) | Commission béniniose des Droits de l'Homme
Belorus (Belaruski) | Permanent Mission of the Republic of Belarus to the United Nations Office in Geneva
Bemba | United Nations Information Centre, Zambia
Bengali | United Nations Department of Public Information, NY
Béti | United Nations Information Centre, Cameroon
Bhojpuri | United Nations Information Centre, India
Bichelamar | Amnesty International, UK
Bikol/Bicolano | Carpio Center for Human Rights, The Philippines
Bora | Coordinadora Nacional de Derechos Humanos, Peru
Bosnian (Cyrillic script) | United Nations Mission In Bosnia and Herzegovina
Bosnian (Latin script) | United Nations Mission In Bosnia and Herzegovina
Breton | Diffusion Multilingue des Droits de l'Homme, France
Bugisnese | United Nations Information Centre, Indonesia
Bulgarian (Balgarski) | United Nations Information Centre, Bulgaria
Burmese/Myanmar | United Nations Information Centre, Myanmar
Cakchiquel | Instituto de Linguistica, Argentina
Campa pajonalino | Coordinadora Nacional de Derechos Humanos, Peru
Candoshi-Shapra | Coordinadora Nacional de Derechos Humanos, Peru
Caquinte | Coordinadora Nacional de Derechos Humanos, Peru
Cashibo-Cacataibo | Coordinadora Nacional de Derechos Humanos, Peru
Cashinahua | Coordinadora Nacional de Derechos Humanos, Peru
Catalan (Català) | United Nations Information Centre, Spain
Cebuano | United Nations Information Centre, The Philippines
Chaa'pala | Office of the High Commissioner for Human Rights - Ecuador Field Office
Chamorro | United Nations Department of Public Information, NY
Changane (Mozambique) | Procuradoria-Geral da Republica, Portugal
Chantyal | Nepal Chhantyal Association
Chayahuita | Coordinadora Nacional de Derechos Humanos, Peru
Chechewa (Nyanja) | Amnesty International, UK
Chhattisgarhi | People’s Watch, India
Chickasaw | Catherine Willmond and Pamela Munro (University of California, Los Angeles, US)
Chin Falam | United Nations Department of Public Information, Myanmar
Chin Hakha | United Nations Department of Public Information, Myanmar
Chin Matu (Nga La) | Chin Human Rights Organization
Chin Tiddim | United Nations Department of Public Information, Myanmar
Chinanteco | United Nations Department of Public Information, NY, in cooperation with the Ministry of Education, Mexico
Chinanteco, Ajitlán | Amnesty International, UK
Chinese (Mandarin) | United Nations Department of Public Information, NY
Chiquitano | Office of the High Commissioner for Human Rights - Bolivia
Chuuk (Trukese) | United Nations Department of Public Information, NY
Cokwe | United Nations Educational, Scientific and Cultural Organization, Angola
Corsican | Diffusion Multilingue des Droits de l'Homme, France
Crioulo (Cabo Verde) | Procuradoria-Geral da Republica, Portugal
Crioulo da Guiné-Bissau (Guinea Bissau Creole) | Procuradoria-Geral da Republica, Portugal
Croatian | Permanent Mission of the Republic of Croatia to the United Nations Office in Geneva
Cymraeg (Welsh) | United Nations Association, Wales
Czech (Cesky) | United Nations Information Centre, NY
Dagaare | United Nations Department of Public Information, NY, jointly with Bureau des langues du Ghana and Association of Negro Business and Professional Women's Clubs
Dagbani | United Nations Department of Public Information, NY, jointly with Bureau des langues du Ghana and Association of Negro Business and Professional Women's Clubs
Dangme | United Nations Department of Public Information, NY, jointly with Bureau des langues du Ghana and Association of Negro Business and Professional Women's Clubs
Danish (Dansk) | United Nations Information Centre, Denmark
Danuwar | Danuwar Jagaran Samiti
Dari | Cooperation Centre for Afghanistan and UNDP/UNOCHA, Pakistan
Dendi | Commission béniniose des Droits de l'Homme
Dhivehi (Maldivian) | Human Rights Commission of the Maldives, Maldives
Dine, Navajo (Navaho) | Navajo Interpreting Services, US
Dinka | United Nations Mission In Sudan
Diola (Jola-Fogny) | Tostan, Senegal
Dioula | United Nations Operation in Cote d'Ivoire
Ditammari | Commission béninoise des Droits de l'Homme, Benin
Dutch (Nederlands) | United Nations Department of Public Information, NY
Dzongkha/Bhutanese | United Nations Information Centre, India
Translation | Translation Source
Edo | United Nations Information Centre, NY
Efik (Ibibio) | United Nations Department of Public Information, NY
Ellinika' (Greek) | United Nations Information Centre, Greece
English | United Nations Department of Public Information, NY
Español (Spanish) | United Nations Department of Public Information, NY
Esperanto | Universala Esperanto Asocio Rotterdam, The Netherlands
Estonian (Eesti) | Estonian Human Rights Institute, Estonia
Euskara (Basque) | United Nations Information Centre, Spain
Even | Amnesty International, UK
Evenki | Office of the High Commissioner for Human Rights - Russian Federation
Ewe/Eve | United Nations Department of Public Information, NY, jointly with Bureau des langues du Ghana and Association of Negro Business and Professional Women's Clubs
Fante | United Nations Department of Public Information, NY, jointly with Bureau des langues du Ghana and Association of Negro Business and Professional Women's Clubs
Faroese | United Nations Information Centre, Denmark
Farsi/Persian | United Nations Information Centre, Iran
Fijian | United Nations Development Programme, Fiji
Filipino (Tagalog) | United Nations Department of Public Information, NY
Finnish | United Nations Information Centre, Denmark
Fiote (Angola) | Procuradoria-Geral da Republica, Portugal
Fon | Commission béninoise des Droits de l'Homme, Benin
Forro | Procuradoria-Geral da Republica, Portugal
Francoprovençal, Fribourg | Anne-Marie Yerly
Francoprovençal, Savoie | Anne-Marie Bimet
Francoprovençal, Valais | Alphonse Dayer
Francoprovençal, Vaud | Marie-Louise Goumaz
French (Français) | United Nations Department of Public Information, NY
Frisian | United Nations Information Centre, Belgium
Friulian (Friulano) | Associazione Proiezione Peters, Italy
Ga | United Nations Department of Public Information, NY, jointly with Bureau des langues du Ghana and Association of Negro Business and Professional Women's Clubs
Gaeilge (Irish Gaelic) | United Nations Department of Public Information, NY
Gagauz | Amnesty International, UK
Gàidhlig Albanach (Scottish Gaelic) | Diffusion Multilingue des Droits de l'Homme, France
Galician (Galego) | United Nations Information Centre, Spain, in cooperation with the Dirección Xeral de Política Lingnistica de la Consellería de Educación y Ordenación Universitaria de la Xunta de Galicia
Garhwali | People’s Watch, India
Garifuna | Coordinadora Nacional de Derechos Humanos, Peru
Georgian | Caucasian Institute, Georgia
German (Deutsch) | UN Department for General Assembly and Conference Management German Translation Service, NY
Gondi, Northern | People’s Watch, India
Gonja | United Nations Department of Public Information, NY, jointly with Bureau des langues du Ghana and Association of Negro Business and Professional Women's Clubs
Greek (Ellinika') | United Nations Information Centre, Greece
Greenlandic (Inuktikut) | United Nations Information Centre, Denmark
Guarani | Consejo Indio de Sur America, Peru
Guarayo |
Guen (Mina) | Commission béninoise des Droits de l'Homme, Benin
Gujarati | United Nations Department of Public Information, NY
Gurung | Tamu Hyula Chhojdhin
Haitian Creole (Kreyol) | United Nations Department of Public Information, NY
Haitian Creole (popular) | United Nations Development Programme, Haiti
Hani | United Nations Development Programme, China
Hankuko (Korean) | United Nations Educational, Scientific and Cultural Organization, Paris
Hausa/Haoussa | Diffusion Multilingue des Droits de l'Homme, France, in cooperation with l'Agence de Coopération Culturelle et Technique
Hawaiian | Hawaii Institute for Human Rights, US
Hebrew | Permanent Mission of Israel to the United Nations Office in Geneva
Hiligaynon | United Nations Information Centre, The Philippines
Hindi | United Nations Department of Public Information, NY
Hmong (Miao) Northern East-Guizhou | United Nations Development Programme, China
Hmong (Miao) Southern East-Guizhou | United Nations Development Programme, China
Hmong (Miao), Sichuan-Guizhou-Yunnan | United Nations Development Programme, China
Ho | People’s Watch, India
Hrvatski (Croatian) | Permanent Mission of the Republic of Croatia to the United Nations Office in Geneva
Huastec, Veracruz | Comisión de Derechos Humanos del Estado de Veracruz
Huasteco | United Nations Information Centre, Mexico in cooperation with the National Human Rights Commission Indigena
Huitoto Murui | Ministerio de Educacion, Peru
Hungarian | United Nations Department of Public Information, NY
Hyolmo | Nepal Hyolmo Social Service Association
Translation | Translation Source
Ibibio | United Nations Department of Public Information, NY
Icelandic (íslenska) | United Nations Information Centre, Denmark
Ido | International Language Ido, Germany
Igbo | Diffusion Multilingue des Droits de l'Homme, France, in cooperation with l'Agence de Coopération Culturelle et Technique
Iloko/Ilocano | Commission on Human Rights, The Philippines
Indonesian | United Nations Information Centre, Indonesia
Interlingua | Union Mundial pro Interlingua, The Netherlands
Inuktikut (Greenlandic) | United Nations Information Centre, Denmark
Inuktitut | Permanent Mission of Canada to the United Nations Office in Geneva
Irish Gaelic | United Nations Department of Public Information, NY
Italian | United Nations Information Centre, Italy
Ivrit (Hebrew) | Permanent Mission of Israel to the United Nations Office in Geneva
Japanese (Nihongo) | United Nations Information Centre, Japan, and the Ministry of Justice and Human Rights NGOs
Javanese | United Nations Information Centre, Indonesia
Jirel | Jirel Association Nepal
Jñatrjo (Mazahua) | United Nations Information Centre, Mexico, in cooperation with the Ministry of Education
Jola-Fogny (Diola) | Tostan, Senegal
Kabardian | Federation of Caucasian Assocations in Turkey (Kaffed)
Kabyè | United Nations Information Centre, Togo
Kanauji | People’s Watch, India
Kannada | Former OHCHR Intern
Kanuri Yerwa | United Nations Information Centre, NY
Kaonde | United Nations Information Centre, Zambia
Kapampangan | Komisyon ng Karapatang Pantao, The Philippines
Karelian | Office of the High Commissioner for Human Rights - Russian Federation
Karen (Pwo) | United Nations Information Centre, Burma
Karen (S'gaw) | United Nations Information Centre, Burma
Kasem | United Nations Department of Public Information, NY, jointly with Bureau des langues du Ghana and Association of Negro Business and Professional Women's Clubs
Kashmiri | United Nations Information Centre, India
Kazakh | United Nations Department of Public Information, Kazakhstan
Khakas | Office of the High Commissioner for Human Rights - Russian Federation
Khalkha (Mongolian) | CHR Technical Cooperation Branch, Mongolia
Kharia | People’s Watch, India
Khasi | Meghalaya Peoples Human Rights Council
Khmer | Cambodia Documentation Commission, Cambodia
Kibushi | Service linguistique du Conseil Général de Mayotte
K'iche' (Quiché) | Instituto de Linguistica, Argentina
Kichwa | Office of the High Commissioner for Human Rights - Ecuador Field Office
Kikongo ya L'Etat (Kikongo/Kituba) | Office of the High Commissioner for Human Rights - Congo Field Office
Kimbundu | United Nations Educational, Scientific and Cultural Organization, Angola
Kinyamwezi (Nyamwezi) | United Nations Development Programme, Tanzania
Kinyarwanda | United Nations Department of Public Information, NY
Kisan | Kisan Community Development Foundation
Koits-Sunuwar | Sunuwar Welfare Society
Komi-Permian | Office of the High Commissioner for Human Rights - Russian Federation
Korean (Hankuko) | United Nations Educational, Scientific and Cultural Organization, Paris
Koulango | United Nations Operation in Cote d'Ivoire
Kpelewo | Ministère de l'Education Nationale, Guinea
Kreyol (Haitian Creole) | United Nations Department of Public Information, NY
Krio | National Commission for Democracy and Human Rights, Sierra Leone
Kurdish | Kurdish Institute, France
Kurmanji | United Nations Development Programme, Iraq
Kurug | People’s Watch, India
Kyrgyz | Permanent Mission of the Kyrgyz Republic to the United Nations Office in Geneva
Ladin | Office for Language Issues and Press Office of the Autonomous Province of Bolzano/Bozen/Balsan
Ladino | Ladinokomunita
Lamnso' (Lám nso') | Executive Committee of the Nso' Language Organisation
Lao | United Nations Department of Public Information, NY
Latin (Latina) | Classes 3AB1 - 3B2 Gymnase de Nyon, Suisse
Latin (Latina) | Liceo Ginnasio Statale "Socrate" Rome, Italy
Latvian | Human Rights Institute of the University of Latvia
Lhomi | Lhomi (Shingsa) Kalyan Kendra and Nepal Lhomi Society
Ligurian | A Compagna di Zoeni
Limba | National Commission for Democracy and Human Rights, Sierra Leone
Limbu | Kirat Yakthung Chumlung
Lingala | United Nations Information Centre, Democratic Republic of the Congo
Lithuanian (Lietuviskai) | Amnesty International, UK
Lobiri | United Nations Operation in Cote d'Ivoire
Low German (Niederdeutsche) | Institute for Low German
Lozi | United Nations Information Centre, Zambia
Luba-Kasai (Tshiluba) | Bibliothèque Nationale du Congo, Democratic Republic of Congo
Luganda/Ganda | NGO, Uganda
Lunda/Chokwe-lunda | United Nations Information Centre, Zambia
Luvale | United Nations Information Centre, Zambia
Luxembourgish (Lëtzebuergeusch) | Ministère de l'Education, Luxembourg
Translation | Translation Source
Macedonian | Macedonian Board, Skopje
Madurese | United Nations Information Centre, Indonesia
Magahi | United Nations Information Centre, India
Magar (Dhut) | Nepal Magar Association
Magyar (Hungarian) | United Nations Department of Public Information, NY
Maithili | People’s Watch, India
Majhi | Nepal Majhi Utthan Sangha
Makonde | United Nations Development Programme, Tanzania
Makua (Mozambique) | Procuradoria-Geral da Republica, Portugal
Malagasy | United Nations Information Centre, Madagascar
Malay (Bahasa Melayu) | Diffusion Multilingue des Droits de l'Homme, France
Malayalam | United Nations Department of Public Information, NY
Maldivian (Dhivehi) | Human Rights Commission of the Maldives, Maldives
Maltese | Maltese University, Malta
Mam | Instituto de Linguistica, Argentina
Maninka | Ministère de l'Education Nationale, Guinea
Manipuri | People’s Watch, India
Maori | New Zealand Human Rights Commission, New Zealand
Maori (Cook Islands) (Rarotongan) | Ministry of Foreign Affairs and Immigration, Cook Islands
Mapudungun (Mapuzgun) | United Nations Information Centre, Argentina/Uruguay
Marathi | United Nations Department of Public Information, NY
Marshallese | United Nations Information Centre, NY
Marwari | United Nations Information Centre, NY
Matsés | Coordinadora Nacional de Derechos Humanos, Peru
Mayan (Yucateco) | United Nations Information Centre, Mexico
Mazahua (Jñatrjo) | United Nations Department of Public Information, NY, in cooperation with the Ministry of Education, Mexico
Mazateco | United Nations Department of Public Information, NY, in cooperation with the Ministry of Education, Mexico
Mbundu (Kimbundu) | United Nations Educational, Scientific and Cultural Organization, Angola
Mende | National Commission for Democracy and Human Rights, Sierra Leone
Mikmaq/Micmac | Permanent Mission of Canada to the United Nations Office in Geneva
Minangkabau | United Nations Information Centre, Indonesia
Miskito | Comité para la Defensa de los Derechos Humanos, Honduras
Mixe | VIDES International
Mixteco | United Nations Information Centre, Mexico
Mizo | People’s Watch, India
Mongolian (Khalkha) | CHR Technical Cooperation Branch, Mongolia
Mooré/More | National Commission for UNESCO, Burkina-Faso
Mozarabic (Ajami) |
Mundari | People’s Watch, India
Ñahñú (Otomí) | Casa del Escritor Indigena, Mexico
Nahuatl | United Nations Information Centre, Mexico
Nanai | Office of the High Commissioner for Human Rights - Russian Federation
Navaho (Dine, Navajo) | Navajo Interpreting Services, US
Ndebele | United Nations Information Centre, Zimbabwe
Nederlands (Dutch) | United Nations Department of Public Information, NY
Nenets | Office of the High Commissioner for Human Rights - Russian Federation
Nepali | United Nations Department of Public Information, NY
Newar | Newa: Dey Daboo
Nganasan | Office of the High Commissioner for Human Rights - Russian Federation
Ngangela (Nyemba) | United Nations Educational, Scientific and Cultural Organization, Angola
Niederdeutsche (Low German) | Institute for Low German
Nigerian Pidgin English | United Nations Information Centre, Nigeria
Nihongo (Japanese) | United Nations Information Centre, Japan, and the Ministry of Justice and Human Rights NGOs
Nivkh | Office of the High Commissioner for Human Rights - Russian Federation
Nomatsiguenga | Coordinadora Nacional de Derechos Humanos, Peru
Northern Sotho/Pedi/Sepedi | Diffusion Multilingue des Droits de l'Homme, France, in cooperation with UNESCO
Norwegian (Bokmål) (Norsk, Bokmål) | United Nations Information Centre, Denmark
Norwegian (Nynorsk) (Norsk, Nynorsk) | Diffusion Multilingue des Droits de l'Homme, France
Nuer | United Nations Mission In Sudan
Nyamwezi (Kinyamwezi) | United Nations Development Programme, Tanzania
Nyanja (Chechewa) | Amnesty International, UK
Nyanja/Chinyanja | United Nations Information Centre, Zambia
Nzema | United Nations Department of Public Information, NY, jointly with Bureau des langues du Ghana and Association of Negro Business and Professional Women's Clubs
Occitan Auvergnat | Diffusion Multilingue des Droits de l'Homme, France
Occitan Languedocien | Diffusion Multilingue des Droits de l'Homme, France
Ogiek | Peter Kiplangat Cheruiyot, Former OHCHR Fellow
Ojibway (Ojibwe) | Permanent Mission of Canada to the United Nations Office in Geneva
Oriya | United Nations Department of Public Information, NY
Oromiffa (Afaan Oromo) | Dema Translation and Editing Service
Osetin (Ossetian) | Kazbek T Boutaev, (University of Pennsylvania, Philadelphia, US)
Oshiwambo (Ndonga) | United Nations Information Centre, Namibia
Otomí (Ñahñú) | Casa del Escritor Indigena, Mexico
Otuho | United Nations Mission In Sudan
Paez | Centro Colombiano de Estudios de Lenguas Aborígenes from the University of Los Andes, Colombia
Pai Koka | Office of the High Commissioner for Human Rights - Ecuador Field Office
Palauan | United Nations Department of Public Information, NY
Papiamentu | Ramon Todd, Former OHCHR Fellow
Pashto/Pakhto | United Nations Development Programme, Pakistan
Persian/Farsi | United Nations Information Centre, Iran
Peuhl | Ministère de l'Education Nationale, Guinea
Picard | Diffusion Multilingue des Droits de l'Homme, Belgium
Pijin (Solomons Pidgin) | United Nations Development Programme, Solomons Islands
Pipil | Office of the High Commissioner for Human Rights and the Government of El Salvador
Polish (Polski) | United Nations Department of Public Information, NY
Ponapean | United Nations Department of Public Information, NY
Portuguese | United Nations Information Centre, Portugal
Prouvençau | Prof. Philippe Blanchet. Université de Rennes, France
Pulaar | United Nations Information Centre, Senegal
Pular | Ministère de l'Education Nationale, Guinea
Punjabi/Panjabi | United Nations Department of Public Information, NY
Purhépecha | United Nations Department of Public Information, Mexico, in cooperation with the Casa del Escritor Indigena
Translation | Translation Source
Q'echi/Kekchi | Instituto de Linguistica, Argentina
Quechua | United Nations Information Centre, Bolivia
Quechua de Ambo-Pasco | Coordinadora Nacional de Derechos Humanos, Peru
Quechua de Ayacucho | Coordinadora Nacional de Derechos Humanos, Peru
Quechua de Cajamarca | Coordinadora Nacional de Derechos Humanos, Peru
Quechua de Cotahuasi (Arequipa) | Coordinadora Nacional de Derechos Humanos, Peru
Quechua de Huamalies (Huanuco) | Coordinadora Nacional de Derechos Humanos, Peru
Quechua de Margos (Sur de Dios de Mayo, Huanuco) | Coordinadora Nacional de Derechos Humanos, Peru
Quechua de Pomabamba (Ancash) | Coordinadora Nacional de Derechos Humanos, Peru
Quechua del Callejon de Huaylas | Coordinadora Nacional de Derechos Humanos, Peru
Quechua del Cusco | Coordinadora Nacional de Derechos Humanos, Peru
Quechua del Norte de Junin | Coordinadora Nacional de Derechos Humanos, Peru
Quichua | Sociedad Ecuatoriana Para Los Derechos Humanos, Instituto de Derechos Humanos-Universidad Central del Ecuador, Fundacion Friedrich Naumann
Rajasthani | People’s Watch, India
Rajbansi | Rajbansi Society Development
Rarotongan (Maori (Cook Islands)) | Ministry of Foreign Affairs and Immigration, Cook Islands
Rhaeto-Romance (Rumantsch) | NGO, Switzerland
Romani | Diffusion Multilingue des Droits de l'Homme, France, in cooperation with Institut National des Langues et Civilisations Orientales
Romanian (Româna) | United Nations Department of Public Information, NY
Rukonzo (Konjo) | NGO, Uganda
Rundi/Kirundi | Ligue burundaise des droits de l'homme, Burundi
Runyankore-rukiga/Nkore-kiga | NGO, Uganda
Russian (Russky) | United Nations Department of Public Information, NY
Sami/Lappish | Diffusion Multilingue des Droits de l'Homme, France
Sammarinese | C. Guidi, Biblioteca Popolare di Serravalle, San Marino
Samoan | United Nations Development Programme, Samoa
Sango (Sangho) | United Nations Development Programme, Central African Republic
Sanskrit | United Nations Information Centre, India
Santhali | People’s Watch, India
Sapara Atupama | Office of the High Commissioner for Human Rights - Ecuador Field Office
Saraiki | Actaf Hussain
Sardinian | Amnesty International, UK
Sarnámi Hindustani | Deep Mahangi, Former OHCHR Fellow
Scots | Amnesty International, UK
Scottish Gaelic | Diffusion Multilingue des Droits de l'Homme, France
Seereer | United Nations Information Centre, Senegal
Serbian (Cyrillic) (Srpski) | Permanent Mission of the Federal Republic of Yugoslavia to the United Nations Office in Geneva
Serbian (Latin) (Srpski) | Permanent Mission of the Federal Republic of Yugoslavia to the United Nations Office in Geneva
Seselwa Creole French |
Shan | United Nations Information Centre, Burma
Sharanahua | Coordinadora Nacional de Derechos Humanos, Peru
Sherpa | Nepal Sherpa Association
Shilluk | United Nations Mission In Sudan
Shimaore | Service linguistique du Conseil Général de Mayotte
Shipibo-Conibo | Coordinadora Nacional de Derechos Humanos, Peru
Shona | United Nations Information Centre, Zimbabwe
Shor | Office of the High Commissioner for Human Rights - Russian Federation
Shqip (Albanian) | United Nations Department of Public Information, NY
Shuar Chicham | Office of the High Commissioner for Human Rights - Ecuador Field Office
Sia Pedee | Office of the High Commissioner for Human Rights - Ecuador Field Office
Sindhi | United Nations Information Centre, India
Sinhala | Human Rights Centre of the Sri Lanka Foundation, Sri Lanka
Siswati | United Nations Information Centre, Swaziland
Slovak (Slovencina) | United Nations Department of Public Information, NY
Slovenian (Slovenscina) | Permanent Mission of the Republic of Slovenia to the United Nations in Geneva
Solomons Pidgin (Pijin) | United Nations Development Programme, Solomons Islands
Somali | Diffusion Multilingue des Droits de l'Homme, France, in cooperation with l'Agence de Coopération Culturelle et Technique
Soninké (Soninkanxaane) | Tostan, Senegal
Sorbian | Permanent Mission of Germany to the United Nations Office in Geneva
Southern Sotho/Sotho/Sesotho/Sutu/Sesutu | Diffusion Multilingue des Droits de l'Homme, South Africa
Spanish (Español) | United Nations Department of Public Information, NY
Sukuma | United Nations Development Programme, Tanzania
Sundanese | United Nations Information Centre, NY
Suomi (Finnish) | United Nations Information Centre, Denmark
Sussu/Soussou/Sosso/Soso/Susu | Ministère de l'Education Nationale, Guinea
Swahili/Kiswahili | United Nations Department of Public Information, NY
Swampy Cree | Permanent Mission of Canada to the United Nations Office in Geneva
Swedish (Svenska) | United Nations Information Centre, Denmark
Tahitian | Diffusion Multilingue des Droits de l'Homme, France
Tajik | The Presidential Apparatus of the Republic of Tajikistan, Tajikistan
Tajpuriya | Tajpuriya Society Welfare Council
Talysh | Human Rights Center of Azerbaijan
Tamang (Tam) | Nepal Tamang Ghedung, Nepal
Tamasheq | Association Tagazt
Tamazight (Beraber) | Observatoire National de Droits de l'Homme, Algeria
Tamil | Human Rights Centre of the Sri Lanka Foundation, Sri Lanka
Tatar | The Committee for the Protection of Human Rights, Republic of Tatarstan
Tchocwe (Angola) | Procuradoria-Geral da Republica, Portugal
Telugu | United Nations Department of Public Information, NY
Tének (Huasteco) | United Nations Department of Public Information, NY, in cooperation with the Ministry of Education, Mexico
Tetum | On-Call Interpreters and Translators Agency, Australia
Thai | United Nations Department of Public Information, NY
Thakali | Thakali Sewa Samittee
Thangmi | Nepal Thangmi Society
Tharu-Dangaura | Tharu Kalyankari Sabha
Themne (Temne) | National Commission for Democracy and Human Rights, Sierra Leone
Tibetan | Office of the Representative of the H.H. the Dalai Lama, Tibet
Ticuna | Coordinadora Nacional de Derechos Humanos, Peru
Tigrinya (Tigrigna) | Dema Translation and Editing Service
Tiv | United Nations Information Centre, NY
Toba | United Nations Information Centre, Argentina/Uruguay
Tojol-a'b'al | United Nations Information Centre, Mexico
Tok Pisin | Baua Baua Popular, Papua New Guinea
Tonga | United Nations Information Centre, Zambia
Tongan (Tonga) | Tongan Human Rights and Democracy Movement, Tonga
Totonaco | United Nations Department of Public Information, NY, in cooperation with the Ministry of Education, Mexico
Trukese (Chuuk) | United Nations Department of Public Information, NY
Tsafiki | Office of the High Commissioner for Human Rights - Ecuador Field Office
Tshiluba (Luba-Kasai) | Bibliothèque Nationale du Congo, Congo
Tshivenda | University of Cape Town, Faculty of Law, South Africa
Turkish (Türkçe) | Secretariat of the Human Rights Coordinating Committee, Turkey
Turkmen | National Commission for UNESCO, Turkeminstan
Tuvan | Office of the High Commissioner for Human Rights - Russian Federation
Tzeltal | United Nations Information Centre, Mexico
Tzotzil | United Nations Information Centre, Mexico
Uighur | United Nations Development Programme, China
Uilta | Office of the High Commissioner for Human Rights - Russian Federation
Ukrainian (Ukrayins'ka) | Ukrainian Union of Jurists, Ukraine
Umbundu | United Nations Educational, Scientific and Cultural Organization, Angola
Uranw-Jhangad | Nepal Jhangad (Uranw) Kodrem Sudhar Karya Guthiyar Aa Karyan Sudhar Samittee
Urarina | Coordinadora Nacional de Derechos Humanos, Peru
Urdu | United Nations Information Centre, Pakistan
Uzbek (Cyrillic) | United Nations Educational, Scientific and Cultural Organization, Uzbekistan
Uzbek (Latin) | United Nations Educational, Scientific and Cultural Organization, Uzbekistan
Vai | Sterling Memorial Library in Yale University
Veps | Office of the High Commissioner for Human Rights - Russian Federation
Vietnamese | United Nations Development Programme, Viet Nam
Vlach | UN Department for General Assembly and Conference Management German Translation Service, NY
Translation | Translation Source
Walloon/Wallon | Waremme - Ville de la Paix, Wallonie, Belgique
Wama | Commission béninoise des Droits de l'Homme, Benin
Wao Tededo | Office of the High Commissioner for Human Rights - Ecuador Field Office
Waray | Komisyon ng Karapatang Pantao, The Philippines
Wayuu | Centro Colombiano de Estudios de Lenguas Aborígenes from the University of Los Andes, Colombia
Welsh (Cymraeg) | United Nations Association Wales, UK
Western Sotho/Tswana/Setswana | Diffusion Multilingue des Droits de l'Homme, South Africa
Wolof | United Nations Information Centre, Senegal
Xhosa | Diffusion Multilingue des Droits de l'Homme, France, in cooperation with UNESCO
Yagua | Coordinadora Nacional de Derechos Humanos, Peru
Yakut | Office of the High Commissioner for Human Rights - Russian Federation
Yanomamö | International Institute of Mary Our Help of the Salesians of Don Bosco
Yao | United Nations Office of the High Comissioner for Human Rights, Geneva
Yapese | United Nations Department of Public Information, NY
Yi | United Nations Development Programme, China
Yiddish | Raphael Finkel and Sholem Berger, University of Kentucky, USA
Yoruba (Yorùbá) | Diffusion Multilingue des Droits de l'Homme, France, in cooperation with l'Agence de Coopération Culturelle et Technique
Yukagir | L'Auravetl'an Foundation, NY
Zapoteco | United Nations Department of Public Information, NY, in cooperation with the Ministry of Education, Mexico
Zapoteco, San Lucas Quiaviní | Felipe H. Lopez and Pamela Munro (University of California, Los Angeles, US)
Zhuang | United Nations Development Programme, China
Zulu | Community Law Centre, South Africa